==> markupy-1.2.0.tar.gz: markupy-1.2.0/src/tests/test_element.py <==
from markupsafe import Markup

from markupy._private.element import (
    CommentElement,
    Element,
    HtmlElement,
    VoidElement,
)
from markupy.tag import Div, Hr, Html, Input, MyElement, Unknown, _


def test_instance_cache() -> None:
    """
    markupy creates element object dynamically. make sure they are reused.
    """
    from markupy import tag

    assert tag.Div is tag.Div
    assert tag.Div is tag.Div()
    assert tag.Div is tag.Div(attr=False)
    assert tag.Div is tag.Div[None]
    assert tag.Div is tag.Div[True]
    assert tag.Div is tag.Div[False]
    assert tag.Div is tag.Div[[]]
    assert tag.Div is tag.Div[[None]]
    assert tag.Div is tag.Div[""]
    assert tag.Div is not tag.Div[0]


def test_element_repr() -> None:
    assert repr(Div("#a")) == """<markupy.Element `<div id="a">`>"""


def test_void_element_repr() -> None:
    assert repr(Hr("#a")) == """<markupy.VoidElement `<hr id="a">`>"""


def test_markup_str() -> None:
    result = str(Div(id="a"))
    assert isinstance(result, str)
    assert isinstance(result, Markup)
    assert result == '<div id="a"></div>'


def test_element_type() -> None:
    assert type(Unknown) is Element
    assert type(MyElement) is Element
    assert type(Div) is Element
    assert type(Input) is VoidElement
    assert type(Html) is HtmlElement
    assert type(_) is CommentElement


def test_comment() -> None:
    assert str(_["Hello"]) == "<!--Hello-->"
    assert str(_[Div["Hello"]]) == "<!--<div>Hello</div>-->"

==> markupy-1.3.0.tar.gz: markupy-1.3.0/src/tests/test_element.py <==
import pytest

from markupy._private.element import (
    CommentElement,
    Element,
    HtmlElement,
    VoidElement,
)
from markupy.exception import MarkupyError
from markupy.tag import Div, Hr, Html, Input, MyElement, Unknown, _


def test_instance_cache() -> None:
    """
    markupy creates element object dynamically. make sure they are reused.
    """
    from markupy import tag

    assert tag.Div is tag.Div
    assert tag.Div is tag.Div()
    assert tag.Div is tag.Div(attr=False)
    assert tag.Div is tag.Div[None]
    assert tag.Div is tag.Div[True]
    assert tag.Div is tag.Div[False]
    assert tag.Div is tag.Div[[]]
    assert tag.Div is tag.Div[[None]]
    assert tag.Div is tag.Div[""]
    assert tag.Div is not tag.Div[0]


def test_element_repr() -> None:
    assert repr(Div("#a")) == """<markupy.Element.div>"""


def test_void_element_repr() -> None:
    assert repr(Hr("#a")) == """<markupy.VoidElement.hr>"""


def test_markup_str() -> None:
    result = str(Div(id="a"))
    assert isinstance(result, str)
    assert result == '<div id="a"></div>'


def test_element_type() -> None:
    assert type(Unknown) is Element
    assert type(MyElement) is Element
    assert type(Div) is Element
    assert type(Input) is VoidElement
    assert type(Html) is HtmlElement
    assert type(_) is CommentElement


def test_comment() -> None:
    assert str(_["Hello"]) == "<!--Hello-->"
    assert str(_[Div["Hello"]]) == "<!--<div>Hello</div>-->"


def test_attributes_after_children() -> None:
    with pytest.raises(MarkupyError):
        Div["hello"](id="world")
